DocumentCameraSideIndicatorStyle class
Side indicator styling configuration for DocumentCameraFrame
Constructors
- DocumentCameraSideIndicatorStyle({bool showSideIndicator = false, double? topPosition, double? rightPosition, Color? sideIndicatorBackgroundColor, Color? sideIndicatorBorderColor, Color? sideIndicatorActiveColor, Color? sideIndicatorInactiveColor, Color? sideIndicatorCompletedColor, TextStyle? sideIndicatorTextStyle})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rightPosition → double?
-
Side indicator position from the right (optional).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showSideIndicator → bool
-
Show the side indicator.
final
- sideIndicatorActiveColor → Color?
-
Color for the active side indicator (optional).
final
- sideIndicatorBackgroundColor → Color?
-
Background color for the side indicator (optional).
final
- sideIndicatorBorderColor → Color?
-
Border color for the side indicator (optional).
final
- sideIndicatorCompletedColor → Color?
-
Color for the completed side indicator (optional).
final
- sideIndicatorInactiveColor → Color?
-
Color for the inactive side indicator (optional).
final
- sideIndicatorTextStyle → TextStyle?
-
Text style for the side indicator (optional).
final
- topPosition → double?
-
Side indicator position from the top (optional).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited