DocumentCameraTitleStyle class
Title styling configuration for DocumentCameraFrame
Constructors
- DocumentCameraTitleStyle({bool showScreenTitle = true, Widget? title, Widget frontSideTitle = const Text('Front Side', style: TextStyle(color: Colors.white, fontSize: 16, fontWeight: FontWeight.w600)), Widget backSideTitle = const Text('Back Side', style: TextStyle(color: Colors.white, fontSize: 16, fontWeight: FontWeight.w600)), Alignment? screenTitleAlignment, EdgeInsets? screenTitlePadding})
-
const
Properties
- backSideTitle → Widget
-
Custom title for back side capture.
Defaults to a white "Back Side" label.
final
- frontSideTitle → Widget
-
Custom title for front side capture.
Defaults to a white "Front Side" label.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenTitleAlignment → Alignment?
-
Alignment of the screen title (optional).
final
- screenTitlePadding → EdgeInsets?
-
Padding for the screen title (optional).
final
- showScreenTitle → bool
-
Whether to show the screen title. Defaults to
true.final - title → Widget?
-
Widget to display as the screen's title (optional).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited